#ifndef _CEGOTUPLESTATE_H_INCLUDED_
#define _CEGOTUPLESTATE_H_INCLUDED_
///////////////////////////////////////////////////////////////////////////////
//                                                         
// CegoTupleState.h
// --------------
// Cego tuple state definition
//                                                         
// Design and Implementation by Bjoern Lemke               
//     
// (C)opyright 2000-2025 Bjoern Lemke
//
// INTERFACE MODULE
//
// Class: CegoTupleState
// 
// Description: 
//
// Status: CLEAN
//
///////////////////////////////////////////////////////////////////////////////

enum CegoTupleState
{    
    COMMITTED, // untouched, visible by all transactions
    INSERTED,  // inserted by current transaction
    DELETED, // deleted by current transaction
    OBSOLETE // an already inserted tuple which has been deleted again
};
#endif




